# sift_pbfs

PBFS (Protobuf File Stream) format for reading and writing protobuf messages to disk.

This crate provides functionality to encode and decode protobuf messages in a chunked format with checksums for data integrity.

**Important Note:** This crate is not intended for external usage. Please refer to the [sift_stream](../sift_stream/README.md)
and [sift_cli](../sift_cli/) crates for intended usage.